==> xmedcon_0.9.9.6.orig.tar.gz: xmedcon-0.9.9.6/source/m-color.h <==
/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
 * filename: m-color.h                                                     *
 *                                                                         *
 * UTIL C-source: Medical Image Conversion Utility                         *
 *                                                                         *
 * purpose      : m-color.c header file                                    *
 *                                                                         * 
 * project      : (X)MedCon by Erik Nolf                                   *
 *                                                                         *
 * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/* $Id: m-color.h,v 1.10 2007/05/21 20:16:10 enlf Exp $
 */

/*
   Copyright (C) 1997-2007 by Erik Nolf

   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
   Free Software Foundation; either version 2, or (at your option) any later
   version.

   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General
   Public License for more details.

   You should have received a copy of the GNU General Public License along
   with this program; if not, write to the Free Software Foundation, Inc.,
   59 Place - Suite 330, Boston, MA 02111-1307, USA.  */


#ifndef __M_COLOR_H__
#define __M_COLOR_H__

/****************************************************************************
                            F U N C T I O N S
****************************************************************************/
int  MdcLoadLUT(char *lutname);
void MdcGrayScale(Uint8 *palette);
void MdcInvertedScale(Uint8 *palette);
void MdcRainbowScale(Uint8 *palette);
void MdcCombinedScale(Uint8 *palette);
void MdcHotmetalScale(Uint8 *palette);
void MdcGetColorMap(int map, Uint8 palette[]);
int MdcSetPresentMap(Uint8 palette[]);

#endif

==> xmedcon_0.10.1.orig.tar.gz: xmedcon-0.10.1/source/m-color.h <==
/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
 * filename: m-color.h                                                     *
 *                                                                         *
 * UTIL C-source: Medical Image Conversion Utility                         *
 *                                                                         *
 * purpose      : m-color.c header file                                    *
 *                                                                         * 
 * project      : (X)MedCon by Erik Nolf                                   *
 *                                                                         *
 * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/* $Id: m-color.h,v 1.11 2007/11/09 23:03:50 enlf Exp $
 */

/*
   Copyright (C) 1997-2007 by Erik Nolf

   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
   Free Software Foundation; either version 2, or (at your option) any later
   version.

   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General
   Public License for more details.

   You should have received a copy of the GNU General Public License along
   with this program; if not, write to the Free Software Foundation, Inc.,
   59 Place - Suite 330, Boston, MA 02111-1307, USA.  */


#ifndef __M_COLOR_H__
#define __M_COLOR_H__

/****************************************************************************
                            F U N C T I O N S
****************************************************************************/
int  MdcLoadLUT(const char *lutname);
void MdcGrayScale(Uint8 *palette);
void MdcInvertedScale(Uint8 *palette);
void MdcRainbowScale(Uint8 *palette);
void MdcCombinedScale(Uint8 *palette);
void MdcHotmetalScale(Uint8 *palette);
void MdcGetColorMap(int map, Uint8 palette[]);
int MdcSetPresentMap(Uint8 palette[]);

#endif
